@@ -1,5 +1,5 @@
 use {
-	crate::{result::Result, Column, Ingredient, Method, Recipe, Row, StorageInner, Value},
+	crate::{result::Result, Column, DatabaseInner, Ingredient, Method, Recipe, Value},
 	rayon::prelude::*,
 	serde::{Deserialize, Serialize},
 	std::{cmp::Ordering, collections::HashMap},
@@ -30,14 +30,11 @@ impl Index {
 	}
 	pub async fn reset(
 		&self,
-		storage: &mut StorageInner,
+		storage: &mut DatabaseInner,
 		table: &str,
 		columns: &[Column],
 	) -> Result<()> {
-		let rows = storage
-			.scan_data(table)
-			.await?
-			.collect::<Result<Vec<(Value, Row)>>>()?;
+		let rows = storage.scan_data(table).await?;
 		let column_index: usize = columns
 			.iter()
 			.enumerate()
