@@ -39,6 +39,10 @@ impl Glue {
 			.clone()
 			.into_iter()
 			.map(|Column { name, .. }| ColumnInfo::of_name(name))
+			.map(|mut col| {
+				col.table.name = table.clone();
+				col
+			})
 			.collect::<Vec<ColumnInfo>>();
 
 		let filter = selection
@@ -80,9 +84,8 @@ impl Glue {
 			.filter_map(|(key, Row(row))| match filter.confirm_constraint(&row) {
 				Ok(false) => None,
 				Err(error) => Some(Err(error)),
-				Ok(true) => {
-					Some(row
-						.iter()
+				Ok(true) => Some(
+					row.iter()
 						.enumerate()
 						.map(|(index, old_value)| {
 							assignments
@@ -102,8 +105,8 @@ impl Glue {
 								.unwrap_or(Ok(old_value.clone()))
 						})
 						.collect::<Result<VecRow>>()
-					.map(|row| (key, row)))
-				}
+						.map(|row| (key, row)),
+				),
 			})
 			.collect::<Result<Vec<(Value, VecRow)>>>()?;
 
@@ -116,8 +119,8 @@ impl Glue {
 		#[cfg(feature = "auto-increment")]
 		self.auto_increment(&database, table, &column_defs, &mut rows)
 			.await?;
-		self.validate_unique(&database, table, &column_defs, &rows, Some(&keys))
-			.await?;
+		/*self.validate_unique(&database, table, &column_defs, &rows, Some(&keys))
+			.await?;*/
 		let keyed_rows: Vec<(Value, Row)> = keys.into_iter().zip(rows).collect();
 		let num_rows = keyed_rows.len();
 
